==> freeciv-2.0.9.tar.bz2: freeciv-2.0.9/client/gui-ftwl/messagewin.c <==
/********************************************************************** 
 Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
***********************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "messagewin.h"

/**************************************************************************
  Popup (or raise) the message dialog; typically triggered by F10.
**************************************************************************/
void popup_meswin_dialog(void)
{
  /* PORTME */
}

/**************************************************************************
  Return whether the message dialog is open.
**************************************************************************/
bool is_meswin_open(void)
{
  /* PORTME */
  return FALSE;
}

/**************************************************************************
  Do the work of updating (populating) the message dialog.
**************************************************************************/
void real_update_meswin_dialog(void)
{
  /* PORTME */
}

==> freeciv-2.1.6.tar.bz2: freeciv-2.1.6/client/gui-ftwl/messagewin.c <==
/********************************************************************** 
 Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
***********************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "messagewin.h"

/**************************************************************************
  Popup (or raise) the message dialog; typically triggered by F10.
**************************************************************************/
void popup_meswin_dialog(bool raise)
{
  /* PORTME */
}

/**************************************************************************
  Return whether the message dialog is open.
**************************************************************************/
bool is_meswin_open(void)
{
  /* PORTME */
  return FALSE;
}

/**************************************************************************
  Do the work of updating (populating) the message dialog.
**************************************************************************/
void real_update_meswin_dialog(void)
{
  /* PORTME */
}
